import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "./view"

import Artix.Handlers
import Artix.Models
import Artix.Core
import Artix.Gui

/**
 * @brief Форма закрытого документа
 */
BasicView {
    id: root
    contentItem: RowLayout {
        spacing: 24
        // Левая часть - список позиций
        GroupBox {
            Style.class: "positionsListBackground"
            Layout.fillHeight: true
            Layout.fillWidth: true
            // Информационные оповещения
            SingleNotification {
                anchors { left: parent.left; right: parent.right; top: parent.top }
                height: 40
                filter: Notification.Info
                interactive: false
            }
            Item {
                width: 240
                height: 310
                anchors.centerIn: parent
                Rectangle {
                    id: thirdCircle
                    anchors.top: parent.top
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: 240
                    radius: width / 2
                    height:  width
                    opacity: 0
                    color: Style.parameter("color.green")
                    Behavior on opacity { OpacityAnimator { duration: 500 } }

                }
                Rectangle {
                    id: secondCircle
                    anchors.centerIn: thirdCircle
                    width: 200
                    radius: width / 2
                    height:  width
                    opacity: 0
                    color: Style.parameter("color.green")
                    Behavior on opacity {
                        SequentialAnimation {
                            OpacityAnimator { duration: 800 }
                            ScriptAction { script: thirdCircle.opacity = 0.15 }
                        }
                    }
                }
                Rectangle {
                    anchors.centerIn: secondCircle
                    width: 160
                    radius: width / 2
                    height:  width
                    color: Style.parameter("color.green")
                    Image {
                        anchors.centerIn: parent
                        source: Style.parameter("icon.checkClosed")
                    }
                    Component.onCompleted: secondCircle.opacity = 0.30
                }
                BasicLabel {
                    anchors.top: thirdCircle.bottom
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.topMargin: 16
                    Style.class: "documentClosedTitle"
                    Tr { code: "documentCloseFormDocumentStatusLabel"; defaultMessage: "Чек закрыт" }
                }
            }
        }
        // Правая часть - элементы управления
        Item {
            Layout.preferredWidth: Math.floor((Screen.desktopAvailableWidth * 0.19 + 374) / 8) * 8
            Layout.fillHeight: true
            // Верхняя панель кассы
            TopPanel {
                id: topPanel
                anchors { left: parent.left; top: parent.top; right: parent.right }
            }
            ColumnLayout {
                anchors { left: parent.left; bottom: parent.bottom; right: parent.right; top: topPanel.bottom }
                anchors { rightMargin: 24; bottomMargin: 24; topMargin: errorNotification.visible ? 0 : 24 }
                spacing: 24
                // Критические оповещения
                SingleNotification {
                    id: errorNotification
                    Layout.fillWidth: true
                    Layout.preferredHeight: 40
                    filter: Notification.Error | Notification.Mode
                    onClicked: topPanel.open()
                }
                Item { Layout.fillHeight: true }
                // Панель действий
                ActionPanel {
                    id: actionPanel
                    Layout.fillWidth: true
                    Layout.preferredHeight: 380
                    context: Context.DocumentClose
                    onClicked: (actionCode) => { handler.processAction(actionCode) }
                }
            }
        }
    }
    // Нижняя панель кассы
    footer: BottomPanel {}

    // Обработчик событий
    DocumentSubtotalHandler {
        id: handler
    }
    // Фильтр и коннектор для работы сканеров
    FormEventFilter {
        id: eventFilter
        onKeyboardData: handler.input(data, rawData, source)
        onCancel: handler.escCommand()
    }
}
