import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "view"

import Artix.Handlers
import Artix.Models
import Artix.Core
import Artix.Gui

/**
 * @brief Форма плиточного меню. Значение currentMenu равное 1 соответствует главному меню ПО
 */
BasicView {
    id: root

    property var menuStack: []  // стек меню
    property int currentMenu: 1 // текущее меню
    property string lastSelectedName
    property var titleStack: [ Utils.makeTr("menuTitleMain", "Главная") ]

    component DrawerSum: GroupBox {
        Style.class: "menuCashDrawer"
        interactive: false
        ColumnLayout {
            anchors { left: parent.left; leftMargin: 64; verticalCenter: parent.verticalCenter }
            spacing: 4
            BasicLabel {
                Style.class: "menuCashDrawerLabel"
                Tr { code: "menuCashDrawerLabel"; defaultMessage: "Сумма в денежном ящике" }
            }
            BasicLabel {
                Style.class: "menuCashDrawerSum"
                text: Utils.formatMoneyItem(SystemInfo.cashDrawerSum())
            }
        }
    }

    header: Item {
        TopPanel { anchors.fill: parent; anchors.leftMargin: 24 }
        height: 72
    }
    ColumnLayout {
        anchors.fill: parent
        anchors.topMargin: 0
        anchors.leftMargin: 24
        anchors.rightMargin: 24
        anchors.bottomMargin: 38
        spacing: 0
        BasicLabel {
            Style.class: "menuTitle"
            Tr { id: titleTr; code: "menuTitleMain"; defaultMessage: "Главная" }
        }
        Item { Layout.preferredHeight: 16 }
        DrawerSum {
            id: drawerSum
            Layout.fillWidth: true
            Layout.preferredHeight: 167.34
            visible: menu.hasMoneyOperation && Config.getLogical("Misc:showCashDrawerSum", true)
        }
        Item { Layout.preferredHeight: 20; visible: drawerSum.visible }
        SwipeMenu {
            id: menu
            Layout.fillWidth: true
            Layout.fillHeight: true

            property bool hasMoneyOperation: false // в меню есть COMMAND_MONEYIN или COMMAND_MONEYOUT

            model: MenuModel {
                onLayoutAboutToBeChanged: menu.hasMoneyOperation = false
                Component.onCompleted: refresh(currentMenu, true)
            }
            rows: drawerSum.visible ? 2 : 3
            delegate: BasicButton {
                Style.class: model.style
                x: menu.cellX(index)
                y: menu.cellY(index)
                width: menu.cellWidth
                height: menu.cellHeight
                padding: 24
                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                iconLayout {
                    preferredWidth: 64
                    preferredHeight: 64
                    alignment: Qt.AlignRight | Qt.AlignBottom
                }
                text: model.actionName
                icon: model.icon
                onClicked: {
                    lastSelectedName = model.actionName
                    handler.itemSelected(model.actionCode)
                }
                Component.onCompleted: {
                    if (handler.checkForMoneyOperation(model.actionCode))
                        menu.hasMoneyOperation = true
                }
            }
        }
    }
    footer: BottomPanel {}

    MenuHandler {
        id: handler
        mainMenu: true
        onGoToMenu: (menuCode) => {
            menu.disableAnimation()
            menuStack.push({ menuCode: currentMenu, pageIndex: menu.pageIndex })
            menu.model.refresh(menuCode, true)
            currentMenu = menuCode
            menu.enableAnimation()
            titleStack.push(Utils.makeTr("undefined", lastSelectedName))
            titleTr.tr = titleStack[titleStack.length - 1]
        }
        onMenuExit: () => {
            menu.disableAnimation()
            var menuItem = menuStack.pop()
            menu.model.refresh(menuItem.menuCode, true)
            currentMenu = menuItem.menuCode
            menu.pageIndex = menuItem.pageIndex
            menu.enableAnimation()
            titleStack.pop()
            titleTr.tr = titleStack[titleStack.length - 1]
        }
    }
}
