import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"

import Artix.Core
import Artix.Gui
import Artix.Models

/**
 * @brief Отображает последнее оповещение по маске filter. Если нет подходящих оповещений, элемент скрывается.
 * @param filter битовая маска типов оповещений
 */
GroupBox {
    id: root
    required property int filter

    property var notification: NotificationStorage.last(filter)
    property int count: NotificationStorage.count(filter)
    property bool hasIcon: notification.type === Notification.Error

    Style.class: notification.type === Notification.Info ? "notificationInfo" : "notificationError"
    visible: notification.type !== Notification.Undefined
    padding: 8
    leftPadding: 12
    rightPadding: 12
    contentItem: Item {
        id: content
        RowLayout {
            anchors.centerIn: parent
            height: parent.height
            spacing: 8
            Image {
                id: icon
                Layout.preferredWidth: 24
                Layout.preferredHeight: 24
                Layout.alignment: Qt.AlignVCenter
                fillMode: Image.PreserveAspectFit
                visible: root.hasIcon
                source: Style.parameter("icon.notificationWarning")
            }
            BasicLabel {
                Style.class: "notificationMessage"
                Layout.fillHeight: true
                Layout.maximumWidth: content.width - (icon.visible ? icon.width + 8 : 0) - (more.visible ? more.width + 8 : 0)
                verticalAlignment: Label.AlignVCenter
                Tr { tr: root.notification.message }
                elide: Label.ElideRight
            }
            BasicLabel {
                id: more
                Style.class: "notificationMore"
                Layout.fillHeight: true
                verticalAlignment: Label.AlignVCenter
                visible: root.count > 1
                Tr {
                    code: "notificationMore"; defaultMessage: "еще %1 уведомлений"
                    args: [ (root.count - 1) ]
                }
            }
        }
    }
    Connections {
        target: NotificationStorage
        function onAdded() {
            root.notification = NotificationStorage.last(root.filter)
            root.count = NotificationStorage.count(root.filter)
        }
        function onRemoved() {
            root.notification = NotificationStorage.last(root.filter)
            root.count = NotificationStorage.count(root.filter)
        }
        function onReplaced() {
            root.notification = NotificationStorage.last(root.filter)
            root.count = NotificationStorage.count(root.filter)
        }
    }
}
