import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../../components"
import "../"

import Artix.Core
import Artix.Gui

/**
 * @brief Панель добавления карты для панели действий
 */
GridLayout {
    id: root
    rowSpacing: 8
    columnSpacing: 8
    columns: 2
    rows: 3

    signal back()
    signal command(string command, var args)
    signal commit(var action, var args)
    property string text
    property var title: Utils.makeTr("documentOpenTitleCardAdd", "Добавление карты")
    property var placeholder: Utils.makeTr("documentOpenInputCardPlaceholder", "Номер карты")
    property var action

    BasicButton {
        Style.class: "actionPanelDelegateHighlighted24px600"
        Layout.preferredWidth: 256
        Layout.preferredHeight: 144
        Layout.row: 0
        Layout.column: 0

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonCardIssuance"; defaultMessage: "Выдать карту" }
        icon: Style.parameter("icon.actionPanel.card")
        onClicked: root.command("COMMAND_CARDISSUANCE", {})
    }
    BasicButton {
        Style.class: "actionPanelDelegate24px600"
        Layout.preferredWidth: 256
        Layout.preferredHeight: 144
        Layout.row: 1
        Layout.column: 1

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonBack"; defaultMessage: "Назад" }
        onClicked: root.back()
    }
    BasicButton {
        Style.class: "actionPanelDelegateContinue"
        Layout.preferredWidth: 256
        Layout.preferredHeight: 144
        Layout.row: 2
        Layout.column: 1

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        icon: Style.parameter("icon.actionPanel.arrow")
        Tr { code: "actionPanelButtonAdd"; defaultMessage: "Добавить" }
        onClicked: accept()
    }
    InlineKeyboard {
        Style.class: "actionPanelDelegate"
        Layout.fillHeight: true
        Layout.preferredWidth: 256
        Layout.row: 1
        Layout.rowSpan: 2
        Layout.column: 0
        layoutType: "digits"
    }

    function accept() {
        let args = {}
        if (root.text.length > 0) {
            args["cardNumber"] = root.text
            args["source"] = InputSource.Keyboard
        }
        root.commit(root.action, args)
    }

    EventFilterConnector {
        receiver: inputField
        filter: FormEventFilter {
            onOk: accept()
            onCancel: back()
        }
    }
}
